using Rational.Test.Ft;
using Rational.Test.Ft.Domain;
using Rational.Test.Ft.Domain.Net;
using Rational.Test.Ft.Script;
using System.Windows.Forms;
using SDK.Sample;

namespace SDK.Sample
{
	/// <summary>
	/// Summary description for ExtendedButtonProxy.
	/// </summary>
	public class SpinControlProxy: ControlWithSubobjectsProxy
	{
		/// <summary>
		/// 
		/// </summary>
		/// <param name="domain"></param>
		/// <param name="channel"></param>
		/// <param name="theAUTObject"></param>
		public SpinControlProxy(NetTestDomainImplementation domain,
			IChannel channel,
			System.Object theAUTObject): base( domain, channel, theAUTObject)
		{
		}

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public override string GetRole()
		{
			return TestObjectRole.ROLE_SPINNER;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public override string GetTestObjectClassName()
		{
			return ProxyTestObject.TEXTGUISUBITEMTESTOBJECT_CLASSNAME;
		}


		/// <summary>
		/// 
		/// </summary>
		/// <param name="pt"></param>
		/// <returns></returns>
		public override object GetChildAtPoint(System.Drawing.Point pt)
		{
			return null;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <returns></returns>
		public override ProxyTestObject[] GetChildren()
		{
			return null;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="point"></param>
		/// <returns></returns>
		protected override System.Collections.ArrayList GetActionArgs(System.Drawing.Point point)
		{
			System.Drawing.Point clientPoint = ((Control)this.theTestObject).PointToClient(point);
			Control controlAtPoint = ((Control)this.theTestObject).GetChildAtPoint(clientPoint);
			if (controlAtPoint is ButtonBase)
			{
				System.Collections.ArrayList args = new System.Collections.ArrayList();
				if (controlAtPoint.Name == "up")
					args.Add(new Rational.Test.Ft.Script.Button("UP"));
				else
					args.Add(new Rational.Test.Ft.Script.Button("DOWN"));
				return args;
			}

			return base.GetActionArgs(point);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="subitem"></param>
		/// <returns></returns>
		protected override SubitemInfo FindSubitem(Subitem subitem)
		{
			System.Diagnostics.Debug.Assert(this.theTestObject is SDK.Sample.SpinControl) ;
			if( !(subitem is Rational.Test.Ft.Script.Button) )
				throw new UnsupportedSubitemException(subitem);
			ButtonSubitemInfo info = new ButtonSubitemInfo();
			info.SetName(((Rational.Test.Ft.Script.Button)subitem).GetName());
			return info;
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="info"></param>
		/// <returns></returns>
		public override System.Drawing.Rectangle GetClippedSubitemRect(SubitemInfo info)
		{
			if( info is ButtonSubitemInfo )
			{
				System.Drawing.Rectangle itemRect = GetSubitemRect(info);
				int height = itemRect.Height;
				itemRect = RectangleToScreen(itemRect); 	
				return itemRect;	
			}
			else
				return base.GetClippedSubitemRect(info);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="subitem"></param>
		/// <returns></returns>
		public override System.Drawing.Rectangle GetSubitemRect(SubitemInfo info)
		{
			if (!( info is ButtonSubitemInfo))
				return base.GetSubitemRect(info);

			string ButtonName = ((ButtonSubitemInfo)info).GetName();
			Control.ControlCollection children = ((Control)this.theTestObject).Controls;
			Control subItemControl;
			if ( ButtonName == "UP") 
				subItemControl = children[1];
			else if ( ButtonName == "DOWN") 
				subItemControl = children[0];
			else
				return new System.Drawing.Rectangle(0,0,0,0); 			
			return subItemControl.Bounds;
		}
		
	}

	/// This simple class is to explain how SubItemInfo class are used
	/// </summary>
	public class ButtonSubitemInfo:SubitemInfo
	{
		private string name;
		public ButtonSubitemInfo():base()
		{
	
		}
		public ButtonSubitemInfo(string name):base()
		{
			this.name = name;
		}
		public void SetName(string name)
		{
			this.name = name;
		
		}
		public string GetName()
		{
			return this.name;
		}
	}
}
